<?php
namespace FlizVideoGenerator\Admin;

class MetaBox {
    public function __construct() {
        add_action('add_meta_boxes', [$this, 'add_meta_box']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function add_meta_box() {
        add_meta_box(
            'fliz_video_generator',
            esc_html__('Fliz Video Generator', 'fliz-video-generator'),
            [$this, 'render_meta_box'],
            'post',
            'side',
            'high'
        );
    }

    public function render_meta_box($post) {
        $video_id = get_post_meta($post->ID, '_fliz_video_id', true);
        ?>
        <div>
            <p>
                <label for="fliz_video_type">
                    <?php echo esc_html__('Video type:', 'fliz-video-generator'); ?>
                </label><br>
                <select name="fliz_video_type" id="fliz_video_type">
                    <option value="article"><?php echo esc_html__('Article', 'fliz-video-generator'); ?></option>
                    <option value="ad"><?php echo esc_html__('Advertisement', 'fliz-video-generator'); ?></option>
                    <option value="product"><?php echo esc_html__('Product', 'fliz-video-generator'); ?></option>
                </select>
            </p>

            <p>
                <label for="fliz_video_format">
                    <?php echo esc_html__('Format:', 'fliz-video-generator'); ?>
                </label><br>
                <select name="fliz_video_format" id="fliz_video_format">
                    <option value="size_16_9">16:9</option>
                    <option value="size_9_16">9:16</option>
                    <option value="square"><?php echo esc_html__('Square', 'fliz-video-generator'); ?></option>
                </select>
            </p>

            <?php if ($video_id): ?>
            <p>
                <label>
                    <?php echo esc_html__('Shortcode:', 'fliz-video-generator'); ?>
                </label><br>
                <code>[fliz_video id="<?php echo esc_attr($video_id); ?>"]</code>
            </p>
            <?php endif; ?>

            <p>
                <button type="button" class="button button-primary" id="generate-video">
                    <?php echo esc_html__('Generate video', 'fliz-video-generator'); ?>
                </button>
            </p>
        </div>
        <?php
    }

    public function enqueue_scripts($hook) {
        if ($hook !== 'post.php' && $hook !== 'post-new.php') {
            return;
        }

        wp_enqueue_script(
            'fliz-admin',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/admin.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );
    }
} 