<?php
namespace FlizVideoGenerator\Shortcode;

class VideoShortcode {
    public function __construct() {
        add_shortcode('fliz_video', [$this, 'render_shortcode']);
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function render_shortcode($atts) {
        $atts = shortcode_atts([
            'id' => '',
        ], $atts, 'fliz_video');

        if (empty($atts['id'])) {
            /* translators: Error message when no video ID is provided in shortcode */
            return esc_html__('Error: Video ID is required in the shortcode.', 'fliz-video-generator');
        }

        $api = new \FlizVideoGenerator\Api\FlizApi();
        $result = $api->get_video_status($atts['id']);

        if (is_wp_error($result)) {
            return sprintf(
                '%s',
                esc_html(
                    sprintf(
                        /* translators: %s: error message */
                        __('Error loading video: %s', 'fliz-video-generator'),
                        $result->get_error_message()
                    )
                )
            );
        }

        if (!isset($result['fliz_video_by_pk']['url'])) {
            /* translators: Error message when video URL is not found in API response */
            return esc_html__('Error: Video URL not found.', 'fliz-video-generator');
        }

        $video_url = $result['fliz_video_by_pk']['url'];
        $video_id = $atts['id'];

        ob_start();
        ?>
        <div class="fliz-video-container" data-video-id="<?php echo esc_attr($video_id); ?>">
            <video controls>
                <source src="<?php echo esc_url($video_url); ?>" type="video/mp4">
                <?php 
                /* translators: Message shown when browser doesn't support video playback */
                echo esc_html__('Your browser does not support the video tag.', 'fliz-video-generator'); 
                ?>
            </video>
        </div>
        <?php
        return ob_get_clean();
    }

    public function enqueue_scripts() {
        wp_enqueue_style(
            'fliz-video',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/css/video.css',
            [],
            FLIZ_VIDEO_GENERATOR_VERSION
        );

        wp_enqueue_script(
            'fliz-video',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/video.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        wp_localize_script('fliz-video', 'flizVideo', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_video_nonce')
        ]);
    }
} 